@@ -1,7 +1,11 @@
+import datetime as dt
 from decimal import Decimal
+from django.db.models import Exists, OuterRef
 from django.dispatch import receiver
 from django.urls import resolve, reverse
+from django.utils.timezone import now
 from django.utils.translation import gettext_lazy as _
+from django_scopes import scopes_disabled
 from i18nfield.strings import LazyI18nString
 from pretix.base.email import get_email_context
 from pretix.base.i18n import language
@@ -13,8 +17,16 @@ from pretix.base.signals import (
     order_changed,
     order_paid,
     order_placed,
+    periodic_task,
 )
-from pretix.control.signals import nav_event, nav_global, nav_organizer
+from pretix.control.signals import (
+    nav_event,
+    nav_event_settings,
+    nav_global,
+    nav_organizer,
+)
+
+from .tasks import send_subevent_reminders
 
 JUVARE_TEMPLATES = [
     "juvare_text_signature",
@@ -23,10 +35,14 @@ JUVARE_TEMPLATES = [
     "juvare_text_order_changed",
     "juvare_text_order_canceled",
     "juvare_text_order_paid",
+    "juvare_reminder_text",
 ]
 
 for settings_name in JUVARE_TEMPLATES:
     settings_hierarkey.add_default(settings_name, "", LazyI18nString)
+settings_hierarkey.add_default("juvare_send_reminders", "false", bool)
+settings_hierarkey.add_default("juvare_reminder_interval", "0", int)
+settings_hierarkey.add_default("juvare_reminder_interval_cutoff", "0", int)
 
 
 @receiver(nav_organizer, dispatch_uid="juvare_nav_organizer")
@@ -52,8 +68,8 @@ def navbar_organizer(sender, request, **kwargs):
     ]
 
 
-@receiver(nav_event, dispatch_uid="juvare_nav_event")
-def navbar_event(sender, request, **kwargs):
+@receiver(nav_event_settings, dispatch_uid="juvare_nav_event_settings")
+def navbar_event_settings(sender, request, **kwargs):
     if not request.user.has_organizer_permission(
         request.organizer, "can_change_organizer_settings", request
     ):
@@ -61,14 +77,13 @@ def navbar_event(sender, request, **kwargs):
     url = resolve(request.path_info)
     return [
         {
-            "label": "Juvare Notify",
+            "label": "Juvare Notify Settings",
             "url": reverse(
                 "plugins:pretix_juvare_notify:organizer-settings",
                 kwargs={
                     "organizer": request.organizer.slug,
                 },
             ),
-            "icon": "mobile-phone",
             "active": url.namespace == "plugins:pretix_juvare_notify"
             and "settings" in url.url_name,
         }
@@ -114,7 +129,7 @@ def control_nav_import(sender, request=None, **kwargs):
                 url.namespace == "plugins:pretix_juvare_notify"
                 and url.url_name == "send"
             ),
-            "icon": "envelope",
+            "icon": "mobile-phone",
             "children": [
                 {
                     "label": _("Send SMS"),
@@ -144,6 +159,18 @@ def control_nav_import(sender, request=None, **kwargs):
                         and url.url_name == "history"
                     ),
                 },
+                {
+                    "label": "Reminders",
+                    "url": reverse(
+                        "plugins:pretix_juvare_notify:reminders",
+                        kwargs={
+                            "organizer": request.organizer.slug,
+                            "event": request.event.slug,
+                        },
+                    ),
+                    "active": url.namespace == "plugins:pretix_juvare_notify"
+                    and url.url_name == "reminders",
+                },
             ],
         },
     ]
@@ -223,3 +250,34 @@ def juvare_order_canceled(order, sender, **kwargs):
 @receiver(order_changed, dispatch_uid="juvare_order_changed")
 def juvare_order_changed(order, sender, **kwargs):
     juvare_order_message(order, "order_changed")
+
+
+@receiver(periodic_task, dispatch_uid="juvare_periodic_reminder")
+def juvare_periodic_reminder(*args, **kwargs):
+    from pretix.base.models.event import Event, Event_SettingsStore, SubEvent
+
+    with scopes_disabled():
+        active_events = (
+            Event.objects.filter(subevents__isnull=False)
+            .distinct()
+            .annotate(
+                send_reminders=Exists(
+                    Event_SettingsStore.objects.filter(
+                        key="juvare_send_reminders",
+                        value="True",
+                        object_id=OuterRef("pk"),
+                    )
+                )
+            )
+            .filter(send_reminders=True)
+        )
+        _now = now()
+        for subevent in SubEvent.objects.filter(
+            event__in=active_events, juvare_reminder__isnull=True, date_from__gt=_now
+        ):
+            if _now > subevent.date_from - dt.timedelta(
+                hours=int(subevent.event.settings.juvare_reminder_interval)
+            ) and _now < subevent.date_from - dt.timedelta(
+                hours=int(subevent.event.settings.juvare_reminder_interval_cutoff)
+            ):
+                send_subevent_reminders.apply_async(kwargs={"subevent": subevent.pk})
