@@ -13,6 +13,11 @@ urlpatterns = [
         views.SenderView.as_view(),
         name="send",
     ),
+    url(
+        r"^control/event/(?P<organizer>[^/]+)/(?P<event>[^/]+)/juvare-notify/reminders$",
+        views.ReminderView.as_view(),
+        name="reminders",
+    ),
     url(
         r"^control/event/(?P<organizer>[^/]+)/(?P<event>[^/]+)/juvare-notify/history/",
         views.SMSHistoryView.as_view(),
